/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Editor.hpp"

Editor::Editor(GraphicSet* ogs, BasicUserInterface* obui, FSHandler* ofsh){
    fsh = ofsh;

    std::string maptoload;
    if (fsh->exists(PathName("save/savegame01.map"))) {
        maptoload = "save/savegame01.map";
    } else {
        maptoload = "icu.map";
    }

    ml = new MapLoader(fsh);
    try{
        ml->loadMap(maptoload);
    }
    catch(Hexception& e){
        std::cerr << e.what();
    }
    map = ml->getMap();
    unit = ml->getUnits();

    gs = ogs;
    bui = obui;

    ui_engine = new UI_Engine(bui->getSize(),Coordinates(0,0),gs,bui);
    engine = new Engine(map, unit, ui_engine, PLAYER0);

    // add EditorMainMenu
    UI_Menu* uim = new UI_Menu(Coordinates(128, 196), Coordinates(0,16), gs, ui_engine);
    emm = new EditorMainMenu(uim);
    engine->addChild(emm);

    playernum = emm->getPlayernumber();
    unittype = emm->getUnittype();
}

Editor::~Editor(){
    delete engine;
    delete map;
    delete ui_engine;
    delete unit;
    delete emm;
    delete ml;
}

RUNMODE Editor::run(){
    emm->refresh();
    emm->print();
    engine->refresh();
    bool endgame = false;
    while (!endgame){
        currinput = bui->getInput(NOINPUT);
        switch (currinput) {
        case NOINPUT:
            editedfield = Coordinates(-1,-1);
            engine->print();
            break;
        case QUIT:
            endgame = true;
            break;
            default:
            switch(engine->getInput(currinput)){
            case QUIT:
                endgame = true;
                break;
            case SCROLL:
                engine->print();
                break;
            case SELECT:
                editedfield = engine->getSelectedField();
                place(true);
                engine->refresh();
                break;
            case LMBHOLD:
                if(editedfield != engine->getSelectedField()){
                    editedfield = engine->getSelectedField();
                    place(true);
                    engine->refresh();
                    engine->print();
                }
                break;
            case RMB:
                editedfield = engine->getSelectedField();
                place(false);
                engine->refresh();
                break;
            case RMBHOLD:
                if(editedfield != engine->getSelectedField()){
                    editedfield = engine->getSelectedField();
                    place(false);
                    engine->refresh();
                    engine->print();
                }
                break;
            case SAVE:
                ml->saveMap("savegame01.map");
                break;
            case MOVEMENU:
                oldpointerpos = bui->getPointerPos();
                while (bui->getInput(NOINPUT) == LMBHOLD){
                    pointerpos = bui->getPointerPos();
                    if (pointerpos == Coordinates(-1,-1)){
                        pointerpos = oldpointerpos;
                    }
                    else{
                        emm->move(pointerpos - oldpointerpos);
                        emm->refresh();
                        emm->print();
                    }
                    oldpointerpos = pointerpos;
                }
                break;
            case SWITCH2P1:
            case SWITCH2P2:
                playernum = emm->getPlayernumber();
                break;
            case SELECTUNIT:
                unittype = emm->getUnittype();
                break;
            default:
                break;
            }
        }
    }
    return LOBBY;
}

void Editor::place(bool doit) {
    Unit* replace = unit->getUnit(editedfield);
    if (!doit) {
        if (replace != NULL) {
            unit->delUnit(replace->getUuid());
        }
        if (unittype == NOUNIT) {
            map->setHeight(editedfield, 0);
        }
        return;
    }
    if (replace == NULL && doit) {
        map->setHeight(editedfield, 1);
        switch (unittype) {
        case MAGICIAN:
            replace = new Magician(editedfield, playernum);
            break;
        case WARRIOR:
            replace = new Warrior(editedfield, playernum);
            break;
        case SCOUT:
            replace = new Scout(editedfield, playernum);
            break;
        case TERRAFORMER:
            replace = new TerraFormer(editedfield, playernum);
            break;
        case SPIRIT:
            replace = new Spirit(editedfield, playernum);
            break;
        default:
            break;
        }
        unit->saveUnit(replace);
        return;
    }
}
