/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/** This is the main function of hexwars.
 * Everything starts here. This function
 * will create basic objects that are
 * needed to run the game. And it will
 * save which runmode is active.*/

#include "shared/RunMode.hpp"
#include "lobby/Lobby.hpp"
#include "client/Client.hpp"
#include "hotseat/HotSeat.hpp"
#include "editor/Editor.hpp"
#include "shared/filesystem/FSHandler.hpp"
#include "shared/gui/BasicUserInterface.hpp"

int main(int argc, char** argv){
#ifndef ALLEGRO4
    if (!al_init()) {
        std::cerr << "Failed to initialize allegro.\n";
        exit(-1);
    }
#endif

    FSHandler* fsh = new FSHandler();

    /* This will initialize the user
     * interface. Since it is not
     * planed to switch the UI while
     * runing the game, there is no
     * pointer used. */
    BasicUserInterface* bui= new BasicUserInterface(fsh);

    /* There will be only one mode
     * runing at the same time. It
     * will be accessible via this
     * pointer. */
    RunMode* runmode;

    GraphicSet* gs = new GraphicSet("modernart", fsh);

    bui->setGraphicSet(gs);


    /* The game needs to have a mode
     * which it is runing in. See in
     * 'shared/RunMode.hpp' which modes
     * are defined. It will start in
     * a menu called 'Lobby'. */
    RUNMODE nextrunmode = LOBBY;

    while(nextrunmode != EXIT){
        // create next runmode to run
        switch(nextrunmode){
        case LOBBY:
            runmode = new Lobby(gs, bui);
            break;
        case HOTSEAT:
            runmode = new HotSeat(gs, bui, fsh);
            break;
        case EDITOR:
            runmode = new Editor(gs, bui, fsh);
            break;
        }

        if(runmode != NULL){

            /* Run the runmode. It will return
             * the next Runmode to run. */
            nextrunmode = runmode->run();
        } else {

            /* There should be a runode initialized,
             * if not, obviously an error occured.
             * Will quit then. */
            return 1;
        }

        /* When stoped runing an object of type runmode is no more
         * needed for some time. So it will be deleted. Set pointer
         * to 'NULL' to prevent mess. */
        delete runmode;
        runmode = NULL;
    }

    delete gs;
    delete bui;
    delete fsh;

#ifndef ALLEGRO4
    al_uninstall_system();
#endif

    return 0;
}
