/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "PlayerSwitchMenu.hpp"

PlayerSwitchMenu::PlayerSwitchMenu(UI_Menu* uim){
    myui = uim;
    display = uim;
    item.push_back(new MenuItem("Switch Player", HEADLINE));
    item.push_back(new MenuItem("Player 1", SELECTED));
    item.push_back(new MenuItem("Player 2", ENABLED));
    item.push_back(new MenuItem("End Round 1", ENABLED));
    item.push_back(new MenuItem("Save Game", ENABLED));
    item.push_back(new MenuItem("Quit Game", ENABLED));
    numofrounds = 1;
    winner = 0;
    p1d = 0;
    p2d = 0;
    selectItem(1);
}

PlayerSwitchMenu::~PlayerSwitchMenu(){
    clear();
}

void PlayerSwitchMenu::setWinner(unsigned char wnr){
    winner = wnr;

    std::string endmsg = "It took Player ";
    endmsg.append(convertInt(winner));
    endmsg.append(" ");
    endmsg.append(convertInt(numofrounds -1));
    endmsg.append(" Rounds to win.");
    delete item[3];
    item[3] = new MenuItem(endmsg, DISABLED);
}


void PlayerSwitchMenu::runItem(unsigned int itemno, int){
    std::string endround("End Round ");
    std::string p1txt("Player 1 (done, ");
    std::string p2txt("Player 2 (done, ");
    switch (itemno){
    case 1:
        currinput = SWITCH2P1;
        p1d++;
        delete item[1];
        p1txt.append(convertInt(p1d));
        p1txt.append("X)");
        item[1] = new MenuItem(p1txt, SELECTED);
        break;
    case 2:
        currinput = SWITCH2P2;
        p2d++;
        delete item[2];
        p2txt.append(convertInt(p2d));
        p2txt.append("X)");
        item[2] = new MenuItem(p2txt, SELECTED);
        break;
    case 3:
        p1d = 0;
        p2d = 0;
        currinput = ENDROUND;
        numofrounds++;
        endround.append(convertInt(numofrounds));
        delete item[1];
        delete item[2];
        delete item[3];
        item[1] = new MenuItem("Player 1", ENABLED);
        item[2] = new MenuItem("Player 2", ENABLED);
        item[3] = new MenuItem(endround, SELECTED);

        break;
    case 4:
        currinput = SAVEGAME;
        break;
    case 5:
        currinput = QUIT;
        break;
    default:
        break;
    }
}
