/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "ConfigMenu.hpp"

ConfigMenu::ConfigMenu(UI_Menu* uim, Lobby* lby, BasicUserInterface* obui){
    // copy pointers for local usage
    display = uim;
    myui = uim;
    lobby = lby;
    bui = obui;

    // get information about window
    fullscreen = bui->getFullscreen();
    res = bui->getSize();

    // initialize items of the menu
    item.push_back(new MenuItem( "Display Configuration", HEADLINE));
    item.push_back(new MenuItem( resolutionButtonText(), SELECTED));
    item.push_back(new MenuItem( "Give me more pixels!", ENABLED));
    item.push_back(new MenuItem( "Less pixels, please!", ENABLED));
    if (fullscreen){
        item.push_back(new MenuItem("Fullscreen (on)", ENABLED));
    }else{
        item.push_back(new MenuItem("Fullscreen (off)", ENABLED));
    }
    item.push_back(new MenuItem("Save settings!", ENABLED));
    item.push_back(new MenuItem("Back", ENABLED));
    selectItem(1);

    // create set of resolutions
    resno = 0;
    resolutions.push_back(Coordinates(  640,  480));
    if(res.x >  640) { resno = 1; }
    resolutions.push_back(Coordinates(  800,  500));
    if(res.x >  800) { resno = 2; }
    resolutions.push_back(Coordinates( 1024,  600));
    if(res.y > 600) { resno = 3; }
    resolutions.push_back(Coordinates( 1024,  768));
    if(res.x > 1024) { resno = 4; }
    resolutions.push_back(Coordinates( 1280,  800));
    if(res.y >  800) { resno = 5; }
    resolutions.push_back(Coordinates( 1280, 1024));
    if(res.x > 1280) { resno = 6; }
    resolutions.push_back(Coordinates( 1680, 1050));
    if(res.x > 1680) { resno = 7; }
    resolutions.push_back(Coordinates( 1920, 1080));
}

ConfigMenu::~ConfigMenu(){
    clear();
    resolutions.clear();
}

void ConfigMenu::runItem(unsigned int itemno, int mod){
    switch (itemno){
    case 1:
        if (mod < 0) {
            if(resno > 0){
                resno--;
            }
        } else {
            if(resno < resolutions.size() - 1){
                resno++;
            }
        }
        res = resolutions[resno];
        delete item[1];
        item[1] = new MenuItem(resolutionButtonText(), SELECTED);
        resetApplyButton();
        refresh();
        break;
    case 2:
        if(resno < resolutions.size() - 1){
            resno++;
        }
        res = resolutions[resno];
        delete item[1];
        item[1] = new MenuItem(resolutionButtonText(), ENABLED);
        resetApplyButton();
        refresh();
        break;
    case 3:
        if(resno > 0){
            resno--;
        }
        res = resolutions[resno];
        delete item[1];
        item[1] = new MenuItem(resolutionButtonText(), ENABLED);
        resetApplyButton();
        refresh();
        break;
    case 4:
        fullscreen = !fullscreen;
        delete item[4];
        if (fullscreen){
            item[4] = new MenuItem("Fullscreen (on)", SELECTED);
        }else{
            item[4] = new MenuItem("Fullscreen (off)", SELECTED);
        }
        resetApplyButton();
        refresh();
        break;
    case 5:
        // save old values
        oldres = bui->getSize();
        oldfullscreen = bui->getFullscreen();
        // set new values to check if bui accepts
        bui->setFullscreen(fullscreen);
        bui->setResolution(res,16);
        // save configuration
        bui->saveUIConfig();
        /* reset to old values because Al5 does not like
         * changing resolutions while running */
        bui->setFullscreen(oldfullscreen);
        bui->setResolution(oldres, 16);
        // inform the user he has to restart the game
        delete item[5];
        item[5] = new MenuItem("Settings saved. "
                               "Restart Hexwars to apply changes.", DISABLED);
        selectItem(6);
        refresh();
        break;
    case 6:
        lobby->changeMenu(MAINMENU);
        break;
    default:
        break;
    }
}

void ConfigMenu::resetApplyButton() {
    delete item[5];
    item[5] = new MenuItem("Save settings!", ENABLED);
}

std::string ConfigMenu::resolutionButtonText() {
    return ("<- Resolution (" + convertInt(res.x) +
            "x" + convertInt(res.y) + ") ->");
}
