/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Server.hpp"

Server::Server(std::string level, FSHandler* ofsh){
    fsh = ofsh;
    map.clear();
    units.clear();

    ml = new MapLoader(fsh);
    ml->loadMap(level);
    mastermap = ml->getMap();
    map.push_back(mastermap);
    masterunits = ml->getUnits();
    units.push_back(masterunits);
}

Server::~Server() {
    delete ml;
}

void Server::endRound(){
#ifdef DEBUG
    masterunits->check();
#endif

    Unit* chkunit;
    Magician* summoner;
    Spirit* summoned;
    for (unsigned int i=0; i < masterunits->getLatestUuid(); i++) {
        chkunit = masterunits->getUnit(i);
        if (chkunit != NULL) {
            if (chkunit->getType() == MAGICIAN) {
                summoner = (Magician*) chkunit;
                summoned = summoner->summonSpirit();
                if ( summoned != NULL ){
                    masterunits->saveUnit(new Spirit(*summoned));
                }
                delete summoned;
            }
        }
    }
}

void Server::doMovement(){
    masterunits->doMovement();
}

void Server::saveGame() {
    ml->saveMap("savegame01.map");
}

Map* Server::getMap(PLAYER plyr){
    return mastermap;
}

UnitContainer* Server::getUnits(PLAYER plyr){
    return masterunits;
}

void Server::updateUnits(UnitContainer* orig, PLAYER plyr){
    masterunits->sync(orig, plyr);
}
