/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Coordinates.hpp"

const bool Coordinates::operator==(const Coordinates& b){
        return ((x == b.x) && (y == b.y));
}

const bool Coordinates::operator!=(const Coordinates& b){
        return !((x == b.x) && (y == b.y));
}

const bool Coordinates::operator<(const Coordinates& b){
        return ((x < b.x) && (y < b.y));
}

const bool Coordinates::operator<<(const Coordinates& b){
        return ((x < b.x) || (y < b.y));
}

const bool Coordinates::operator>(const Coordinates& b){
	return ((x > b.x) && (y > b.y));
}

const bool Coordinates::operator>>(const Coordinates& b){
        return ((x > b.x) || (y > b.y));
}

Coordinates& Coordinates::operator=(const Coordinates& b){
	x = b.x;
	y = b.y;
	return *this;
}

const Coordinates Coordinates::operator+(const Coordinates& b){
        Coordinates a;
        a.x = x + b.x;
        a.y = y + b.y;
        return a;
}

Coordinates& Coordinates::operator+=(const Coordinates& b){
        x += b.x;
        y += b.y;
        return *this;
}

const Coordinates Coordinates::operator-(const Coordinates& b){
        Coordinates a;
        a.x = x - b.x;
        a.y = y - b.y;
        return a;
}

Coordinates Coordinates::operator-=(const Coordinates& b){
        x -= b.x;
        y -= b.y;
        return *this;
}

const Coordinates Coordinates::operator*(const int& fact){
        Coordinates a;
        a.x = x * fact;
        a.y = y * fact;
        return a;
}

const Coordinates Coordinates::operator/(const int& div){
        Coordinates a;
        a.x = x /div;
        a.y = y /div;
        return a;
}

Coordinates::Coordinates(){
        x = -1;
        y = -1;
}

Coordinates::Coordinates(int ox, int oy){
    x = ox;
    y = oy;
}

Coordinates::Coordinates(const Coordinates& orig) {
    x = orig.x;
    y = orig.y;
}

Coordinates::~Coordinates(){
    ;
}

const unsigned int Coordinates::distanceTo(const Coordinates& target){
    int distance = abs(target.x-x);
    if (abs(target.y-y) <= distance/2){
        return distance;
    }
    else{
        if (distance%2 == 1){
            if  (target.x%2 == 1){
                if (y < target.y){
                    distance += 1;
                }
            }
            else{
                if (y > target.y){
                    distance += 1;
                }
            }
        }
        distance /= 2;
        distance += abs(target.y-y);
    }
    return distance;
}

