/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __COORDINATES__H__
#define __COORDINATES__H__

#include <stdlib.h>
#include <string>

/** \brief two dimensional vector that works in hex-based space
 *
 *  since Coordinates supports hex-based operations like distanceTo()
 *  and Cartesian operations like operator-() it can be used in hex-based
 *  space (e.g. on the Map) and in Cartesian space (e.g. on the display)
 */

class Coordinates{
public:
    /// sets x and y to -1
    Coordinates();

    /// sets x and y to selected values
    Coordinates(int, int);

    Coordinates(const Coordinates&);

    /// does nothing
    ~Coordinates();

    /// true when A and B are equal
    const bool operator==(const Coordinates&);

    /// true when x-s or y-s are unequal */
    const bool operator!=(const Coordinates&);

    /// true when x and y  are smaller
    const bool operator<(const Coordinates&);

    /// true when x or y  are smaller
    const bool operator<<(const Coordinates&);

    /// true when x and y are bigger
    const bool operator>(const Coordinates&);

    /// true when x or y are bigger
    const bool operator>>(const Coordinates&);

    /// sets x and y to values of second Coordinates
    Coordinates& operator=(const Coordinates&);

    /// adds values of x-s and y-s
    const Coordinates operator+(const Coordinates&);

    /// adds values of x-s and y-s to first Coordinates
    Coordinates& operator+=(const Coordinates&);

    /// subtracts values of x-s and y-s to first Coordinates
    const Coordinates operator-(const Coordinates&);

    /// subtracts values of x-s and y-s of first Coordinates
    Coordinates operator-=(const Coordinates&);

    /// multiplies x and y by int
    const Coordinates operator*(const int&);

    /// divides x and y by int
    const Coordinates operator/(const int&);

    /// distance between both Coordinates in hex-based space
    const unsigned int distanceTo(const Coordinates& target);

    /// the vectors first component
    int x;

    /// the vectors second component
    int y;
};

#endif	/* __COORDINATES__H__ */

