/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAPLOADER_SWITCH
#define MAPLOADER_SWITCH

#ifdef ALLEGRO4
class BstMapLoader;
typedef BstMapLoader MapLoader;
#include "boost/BstMapLoader.hpp"
#else
class Al5MapLoader;
typedef Al5MapLoader MapLoader;
#include "allegro5/Al5MapLoader.hpp"
#endif

#endif // MAPLOADER_SWITCH

#ifndef MAPLOADER_HPP
#define MAPLOADER_HPP

#include "FSHandler.hpp"
#include "../definitions/Map.hpp"
#include "../misc/Exceptions.hpp"
#include "../units/UnitContainer.hpp"
#include "../units/Unit.hpp"
#include "../units/Magician.hpp"
#include "../units/Scout.hpp"
#include "../units/TerraFormer.hpp"
#include "../units/Warrior.hpp"

class VirtualMapLoader {
public:
    VirtualMapLoader();

    void loadMap(std::string levelname);
    void saveMap(std::string savegame);

    virtual Map* getMap();
    void setMap(Map*);

    virtual UnitContainer* getUnits();
    void setUnits(UnitContainer*);
protected:
    PathName savepath;

    Map* map;
    UnitContainer* player;

    Unit* unit;

    FSHandler* fsh;

    virtual void loadMapFromDisk(PathName) =0;

    virtual void saveMapToDisk(PathName) =0;

    void parse_HWmap_V01(unsigned int [32][32]);

    int hw01_unit(int);
    int hw01_owner(int);

    void prepareSavePath();
};

#endif // MAPLOADER_HPP
