/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2012  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef AL5MAPLOADER_HPP
#define AL5MAPLOADER_HPP

#include <fstream>

#include "../MapLoader.hpp"

class Al5MapLoader : public VirtualMapLoader {
public:
    Al5MapLoader(FSHandler*);
    ~Al5MapLoader();
private:
    std::ifstream mapload;

    /** \brief loads map from filesystem
     *
     * Acceses filesystem and loads first ten characters
     * of the map so it can destiguish the map's version.
     * Than delegates further work to methods specific for
     * HWmap's version.
     */
    void loadMapFromDisk(PathName fullpath);

    void saveMapToDisk(PathName fullpath);

    /** \brief HWmap_V01-part of loadMapFromDisk(PathName)
     *
     * Prepares everything so that parse_HWmap_V01() can
     * just parse an 2D-array of integer into Map and
     * UnitContainer without any further FS I/O.
     * creates UnitContainer and Map of the correct size.
     */
    void load_HWmap_V01();
};

#endif // AL5MAPLOADER_HPP
