 /* Hexwars - A Hexagonal Turn Based Strategy Game
  * Copyright (C) 2009-2011  Patrik Schönfeldt
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#include "BstFSHandler.hpp"

BstFSHandler::BstFSHandler(){
    contdir = "/usr/share/hexwars/";
    addSearchDir(contdir);
    fs::path homedir = getenv("HOME");
    homedir /= ".hexwars";
    addSearchDir( PathName(homedir) );
    addSearchDir("./");
}

BstFSHandler::~BstFSHandler(){
    searchdirs.clear();
}

void BstFSHandler::prepareDirectory(PathName dir){
    if (dir == PathName("")) {
        throw Hexception("Tried to prepare"
                         "directory with empty name.");
        return;
    }
    fs::path dirname = dir.bstPath();

    /* TODO: std::cerr and std::cout are not
     * fully compatible with allegro.
     * It might be a good idea to use exceptions instead.
     */
    try {
        fs::file_status s = fs::status(dirname);
        if (!fs::is_directory(s)){
            /* for prepareDirectory dirnames should be directories
             * if not you might have a problem */
            if (!fs::exists(dirname)){
                /* if the directory does not exist everything is fine
                 * just create the directory */
                fs::create_directory(dirname);
                std::cout << "Warning: Directory '" << dirname.string()
                          << "' not found. Created it.\n";
            } else {
                /* if there is a file with that name you have a problem
                 * let the user check what's up. */
                std::cerr << "Error: '" << dirname.string()
                          << "' is not a directory (but should be one)."
                             "Will now quit.\n";
                exit(1);
            }
        }
    } catch (fs::filesystem_error &e) {
        std::cerr << e.what() << std::endl;
    }
}

void BstFSHandler::setExeDir(PathName exename){
    exedir = PathName(exename.bstPath().parent_path().parent_path());
    addSearchDir(exedir);
    addSearchDir(PathName(exedir.bstPath().parent_path()));
}

bool BstFSHandler::fileExists(PathName path) {
    return fs::exists(path.bstPath());
}
