/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "BstMapLoader.hpp"

//the constructor initiates everything the MapLoader has to do
BstMapLoader::BstMapLoader(FSHandler* ofsh){
    fsh = ofsh;
}

void BstMapLoader::loadMapFromDisk(PathName fullpath) {
    mapload.open(fullpath.c_str());
    char Version[10];
    for (int i=0;i<9;i++){
        mapload >> Version[i];
    }
    Version[9] = '\0';
        /* check version string of the map; later versions
         * of hexwars may support greater levels, more units. */
    if (std::string(Version) == "HWmap_V01"){
        load_HWmap_V01();
    } else {
        throw Hexception("Unknown map format or map not found.\n");
    }
    return;
}

void BstMapLoader::saveMapToDisk(PathName fullpath) {
    // this will be a switch to determine version of HWmap
    if (true) {
        std::ofstream ofs;
        ofs.open(fullpath.c_str(), std::fstream::trunc);
        ofs << "HWmap_V01 " << map->getSize().x << " " << map->getSize().y << std::endl;
        for (int y=0; y < map->getSize().y; y++) {
            for (int x=0; x < map->getSize().x; x++) {
                unit = player->getUnit(Coordinates(x,y));
                if (unit == NULL) {
                    switch(map->getTerrain(Coordinates(x,y))) {
                    case WATER:
                        ofs << "00";
                        break;
                    case GRASS:
                        ofs << "01";
                        break;
                    default:
                        ofs << "00";
                        break;
                    }
                } else {
                    ofs << unit->getOwner();
                    ofs << unit->getType();
                }
            if (x < map->getSize().x - 1)
                ofs << " ";
            }
            ofs << std::endl;
        }
        ofs.close();
    }
    return;
}

void BstMapLoader::load_HWmap_V01() {
    //load the size of the map
    unsigned int X, Y;
    mapload >> X;
    mapload >> Y;
    map = new Map(X,Y,1);
    player = new UnitContainer(map);

    //load all data into a 2D array
    unsigned int tmpmap[32][32];
    for (unsigned int y=Y; y>0; y--) {
        for (unsigned int x=0; x<X; x++) {
            mapload >> (tmpmap[x][Y-y]);
        }
    }

    if(!mapload.good()){
        throw Hexception("Error loading map.\n");
        mapload.close();
        return;
    }

    mapload.close();

    //parse data from 2D array
    parse_HWmap_V01(tmpmap);
}

void BstMapLoader::load_HWmap_V02() {
    //load the size of the map
    unsigned int X, Y;
    mapload >> X;
    mapload >> Y;
    map = new Map(X,Y,1);

    //set hight
    char h;
    for (unsigned int i=0; i < X; i++) {
        for (unsigned int j=0; j < Y; j++) {
            mapload >> h;
            map->setHeight(i,j,h);
        }
    }
}

BstMapLoader::~BstMapLoader(){
    mapload.clear();
}
