/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* The MapLoader does nothing but to load the map.
 * It will automatically fill the given PlayerData
 * on creation. To get the Map, use loadedMap(). */

#ifndef _BSTMAPLOADER_H
#define	_BSTMAPLOADER_H

#include <vector>
#include <fstream>
#include <exception>
#include <string>
#include <boost/filesystem.hpp>
#include <boost/filesystem/fstream.hpp>

#include "../MapLoader.hpp"

namespace fs = boost::filesystem;

class BstMapLoader : public VirtualMapLoader {
public:
    BstMapLoader(FSHandler*);
    ~BstMapLoader();
private:
    fs::ifstream mapload;

    /** \brief loads map from filesystem
     *
     * Acceses filesystem and loads first ten characters
     * of the map so it can destiguish the map's version.
     * Than delegates further work to methods specific for
     * HWmap's version.
     */
    void loadMapFromDisk(PathName fullpath);

    void saveMapToDisk(PathName fullpath);

    void load_HWmap_V01();
    void load_HWmap_V02();
};

#endif	/* _MAPLOADER_H */
