/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "BstPathName.hpp"

BstPathName::BstPathName() {
    ;
}

BstPathName::BstPathName(const char* path) {
    name = path;
}

BstPathName::BstPathName(std::string path) {
    name = path;
}

BstPathName::BstPathName(const BstPathName& orig) {
    name = orig.name;
}

BstPathName::BstPathName(fs::path path) {
    setPathName( path );
}

BstPathName::~BstPathName() {
    name.clear();
}

std::string BstPathName::string() {
    return name.string();
}

const char* BstPathName::c_str() {
    return string().c_str();
}

fs::path BstPathName::bstPath() {
    return name;
}

bool BstPathName::exists() {
    return fs::exists(name);
}

BstPathName BstPathName::operator=(const char* oname) {
    name = fs::path(oname);
    return *this;
}

BstPathName BstPathName::operator=(BstPathName orig) {
    name = orig.name;
    return *this;
}

BstPathName BstPathName::operator/=(const char* subdir) {
    append(subdir);
    return *this;
}

BstPathName BstPathName::operator/=(std::string subdir) {
    append(subdir);
    return *this;
}

BstPathName BstPathName::operator/=(BstPathName subdir) {
    name /= subdir.bstPath();
    return *this;
}

BstPathName BstPathName::operator/(const char* subdir) {
    return name/subdir;
}

void BstPathName::append(const char * subdir) {
    name /= fs::path(subdir);
}

void BstPathName::append(std::string subdir) {
    name /= fs::path(subdir);
}

void BstPathName::setPathName(std::string path){
    name = path;
}

void BstPathName::setPathName(const char* path){
    name = path;
}

void BstPathName::setPathName(fs::path path){
    name = path;
}
