/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al4GraphicSet.hpp"


Al4GraphicSet::Al4GraphicSet(std::string ographicsdir, FSHandler* ofsh){
    fsh = ofsh;
    graphicsdir = "graphics/bitmap/128x64/";
    graphicsdir /= ographicsdir;
    graphicsdir = fsh->getFullPath(graphicsdir);
    // load the set of graphics
    setNull();
    loadGraphics();
}

void Al4GraphicSet::setGraphicSet(std::string ographicsdir){
    graphicsdir = "graphics/bitmap/128x64/";
    graphicsdir /= ographicsdir;
    /* need to unload and reload since graphics
     * where already loaded by constructor
     */
    unLoadGraphics();
    setNull();
    loadGraphics();
}

Al4GraphicSet::~Al4GraphicSet(){
    unLoadGraphics();
}

void Al4GraphicSet::loadGraphics(){
    grass1      = load_bitmap((graphicsdir/"/grass1.tga").c_str(), NULL);
    water1      = load_bitmap((graphicsdir/"/water1.tga").c_str(), NULL);
    fog         = load_bitmap((graphicsdir/"/fog.tga").c_str(), NULL);
    fogtile     = load_bitmap((graphicsdir/"/tile_fog.tga").c_str(), NULL);
    focus[0]   = load_bitmap((graphicsdir/"/focus-summon.tga").c_str(), NULL);
    focus[1]   = load_bitmap((graphicsdir/"/focus1.tga").c_str(), NULL);
    focus[2]   = load_bitmap((graphicsdir/"/focus2.tga").c_str(), NULL);
    cursor[0]   = load_bitmap((graphicsdir/"/pointer.tga").c_str(), NULL);
    cursor[1]   = load_bitmap((graphicsdir/"/pointer1.tga").c_str(), NULL);
    cursor[2]   = load_bitmap((graphicsdir/"/pointer2.tga").c_str(), NULL);
    spirit[0]   = load_bitmap((graphicsdir/"/spirit0.tga").c_str(), NULL);
    spirit[1]   = load_bitmap((graphicsdir/"/spirit1.tga").c_str(), NULL);
    spirit[2]   = load_bitmap((graphicsdir/"/spirit2.tga").c_str(), NULL);
    magician[0] = load_bitmap((graphicsdir/"/magician0.tga").c_str(), NULL);
    magician[1] = load_bitmap((graphicsdir/"/magician1.tga").c_str(), NULL);
    magician[2] = load_bitmap((graphicsdir/"/magician2.tga").c_str(), NULL);
    warrior[0]  = load_bitmap((graphicsdir/"/warrior0.tga").c_str(), NULL);
    warrior[1]  = load_bitmap((graphicsdir/"/warrior1.tga").c_str(), NULL);
    warrior[2]  = load_bitmap((graphicsdir/"/warrior2.tga").c_str(), NULL);
    scout[0]    = load_bitmap((graphicsdir/"/scout0.tga").c_str(), NULL);
    scout[1]    = load_bitmap((graphicsdir/"/scout1.tga").c_str(), NULL);
    scout[2]    = load_bitmap((graphicsdir/"/scout2.tga").c_str(), NULL);
    terraf[0]   = load_bitmap((graphicsdir/"/terraf0.tga").c_str(), NULL);
    terraf[1]   = load_bitmap((graphicsdir/"/terraf1.tga").c_str(), NULL);
    terraf[2]   = load_bitmap((graphicsdir/"/terraf2.tga").c_str(), NULL);
}

void Al4GraphicSet::unLoadGraphics(){
    destroy_bitmap(grass1);
    destroy_bitmap(water1);
    destroy_bitmap(fog);
    destroy_bitmap(fogtile);
    for(int i=0; i<=2; i++){
        destroy_bitmap(focus[i]);
        destroy_bitmap(cursor[i]);
        destroy_bitmap(magician[i]);
        destroy_bitmap(warrior[i]);
        destroy_bitmap(scout[i]);
        destroy_bitmap(terraf[i]);
    }
}

void Al4GraphicSet::setNull(){
    grass1 = NULL;
    water1 = NULL;
    fog = NULL;
    fogtile = NULL;
    for(int i=0; i<=2; i++){
        focus[i] = NULL;
        cursor[i] = NULL;
        magician[i] = NULL;
        warrior[i] = NULL;
        scout[i] = NULL;
        terraf[i] = NULL;
    }
}
