/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* The Al4GraphicSet provides all the graphics
 * needed by the UI_Engine to display units,
 * terrains and other stuff. */

#ifndef __Al4GraphicSet__H__
#define __Al4GraphicSet__H__

#include <allegro.h>
#include <string>
#include <vector>

#include "../../filesystem/PathName.hpp"
#include "../../filesystem/FSHandler.hpp"

class Al4GraphicSet{
public:
    Al4GraphicSet(std::string, FSHandler*);
    ~Al4GraphicSet();

    /// lets you choose a new(!) Al4GraphicSet
    void setGraphicSet(std::string);
    
    // bitmaps needed to display terrains
    BITMAP* grass1;
    BITMAP* water1;
    
    // used to highlight selected units
    BITMAP* focus[3];

    BITMAP* fogtile;
    BITMAP* fog;
    
    // bitmaps for the pointer
    BITMAP* cursor[3];
    
    // bitmaps needed to display units
    BITMAP* spirit[3];
    BITMAP* magician[3];
    BITMAP* warrior[3];
    BITMAP* scout[3];
    BITMAP* terraf[3];

private:
    FSHandler* fsh;

    // saves which Al4GraphicSet is currently used
    PathName graphicsdir;

    void loadGraphics();
    // loads the graphics

    // unloads the graphics
    void unLoadGraphics();

    /** sets all pointers to NULL */
    void setNull();
};

#endif /* __Al4GraphicSet__H__ */
