/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al4UI.hpp"

Al4UI::Al4UI(){
    ;
}

Al4UI::Al4UI(Coordinates size, Coordinates pos, GraphicSet* gs, Al4UI* par){
    init(size, pos, gs, par);
}

Al4UI::~Al4UI(){
    destroy_bitmap(buffer);
    destroy_bitmap(TLB);
}

void Al4UI::lockScreen(bool doit){
    if(doit){
        acquire_bitmap(buffer);
    }else{
        release_bitmap(buffer);
    }
}

void Al4UI::setGraphicSet(GraphicSet* gs){
    graphics = gs;
}

void Al4UI::print(){
    masked_blit( buffer, parent->TLB, 0, 0, pos.x, pos.y, size.x, size.y);
    masked_blit( TLB, parent->TLB, 0, 0, pos.x, pos.y, size.x, size.y);
    parent->print();
}

void Al4UI::clearBlack(){
    clear_bitmap(buffer);
}

void Al4UI::clear(){
    clear_to_color(buffer, makecol(255, 0, 255));
}

void Al4UI::clearTLB(){
    clear_to_color(TLB, makecol(255, 0, 255));
}

INPUTTYPE Al4UI::getInput(INPUTTYPE currinput){
    if( (pos < Coordinates(mouse_x, mouse_y)) && (Coordinates(mouse_x, mouse_y) < pos+size) ){
        return HOVER;
    }
    return NOINPUT;
}

Coordinates Al4UI::getPointerPos(){
    Coordinates mp = Coordinates(mouse_x, mouse_y);
    if(pos < mp && mp < pos + size){
        return mp - pos;
    }
    else{
        return Coordinates(-1, -1);
    }
}

void Al4UI::changePos(Coordinates dp){
    pos += dp;
    parent->clearTLB();
}

Coordinates Al4UI::getSize(){
    return size;
}

void Al4UI::setSize(Coordinates s){
    size = s;
    destroy_bitmap(TLB);
    TLB = create_bitmap(size.x, size.y);
    destroy_bitmap(buffer);
    buffer = create_bitmap(size.x, size.y);
    clear_to_color(buffer, makecol(255, 0, 255));
    clear_to_color(TLB, makecol(255, 0, 255));
}

void Al4UI::printText(std::string text, Coordinates pos){
    textout_ex(buffer, font, text.c_str(), pos.x, pos.y,  makecol(255,255,255), -1);
}

void Al4UI::init(Coordinates s, Coordinates p, GraphicSet* gs, Al4UI* par){
    graphics = gs;
    parent = par;
    pos = p;
    size = s;
    buffer = create_bitmap(size.x, size.y);
    TLB = create_bitmap(size.x, size.y);
    clear_to_color(buffer, makecol(255, 0, 255));
    clear_to_color(TLB, makecol(255, 0, 255));
}
