/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al5GraphicSet.hpp"


Al5GraphicSet::Al5GraphicSet(std::string ographicsdir, FSHandler* ofsh){
    fsh = ofsh;
    graphicsdir = "graphics/bitmap/128x64/";
    graphicsdir /= ographicsdir;
    graphicsdir = fsh->getFullPath(graphicsdir);

    // load the set of graphics
    setNull();
    loadGraphics();
}

void Al5GraphicSet::setGraphicSet(std::string ographicsdir){
    graphicsdir = "graphics/bitmap/128x64/";
    graphicsdir /= ographicsdir;
    graphicsdir = fsh->getFullPath(graphicsdir);

    /* need to unload and reload since graphics
     * where already loaded by constructor
     */
    unLoadGraphics();
    setNull();
    loadGraphics();
}

Al5GraphicSet::~Al5GraphicSet(){
    unLoadGraphics();
}

void Al5GraphicSet::loadGraphics(){
    try {
        grass1        = loadBitmap("grass1.tga");
        water1        = loadBitmap("water1.tga");
        fog           = loadBitmap("fog.tga");
        fogtile       = loadBitmap("tile_fog.tga");
        focus[0]     = loadBitmap("focus-summon.tga");
        focus[1]     = loadBitmap("focus1.tga");
        focus[2]     = loadBitmap("focus2.tga");
        cursor[0]     = loadBitmap("pointer.tga");
        cursor[1]     = loadBitmap("pointer1.tga");
        cursor[2]     = loadBitmap("pointer2.tga");
        spirit[0]     = loadBitmap("spirit0.tga");
        spirit[1]     = loadBitmap("spirit1.tga");
        spirit[2]     = loadBitmap("spirit2.tga");
        magician[0]   = loadBitmap("magician0.tga");
        magician[1]   = loadBitmap("magician1.tga");
        magician[2]   = loadBitmap("magician2.tga");
        warrior[0]    = loadBitmap("warrior0.tga");
        warrior[1]    = loadBitmap("warrior1.tga");
        warrior[2]    = loadBitmap("warrior2.tga");
        scout[0]      = loadBitmap("scout0.tga");
        scout[1]      = loadBitmap("scout1.tga");
        scout[2]      = loadBitmap("scout2.tga");
        terraf[0]     = loadBitmap("terraf0.tga");
        terraf[1]     = loadBitmap("terraf1.tga");
        terraf[2]     = loadBitmap("terraf2.tga");
    } catch(Hexception& e){
        std::cerr << e.what();
        exit(-1);
    }
}

void Al5GraphicSet::unLoadGraphics(){
    al_destroy_bitmap(grass1);
    al_destroy_bitmap(water1);
    al_destroy_bitmap(fog);
    al_destroy_bitmap(fogtile);
    for(int i=0; i<=2; i++){
        al_destroy_bitmap(focus[i]);
        al_destroy_bitmap(cursor[i]);
        al_destroy_bitmap(magician[i]);
        al_destroy_bitmap(warrior[i]);
        al_destroy_bitmap(scout[i]);
        al_destroy_bitmap(terraf[i]);
    }
}

void Al5GraphicSet::setNull(){
    grass1 = NULL;
    water1 = NULL;
    fog = NULL;
    fogtile = NULL;
    for(int i=0; i<=2; i++){
        focus[i] = NULL;
        cursor[i] = NULL;
        magician[i] = NULL;
        warrior[i] = NULL;
        scout[i] = NULL;
        terraf[i] = NULL;
    }
}

ALLEGRO_BITMAP* Al5GraphicSet::loadBitmap(const char* name) {
    ALLEGRO_BITMAP* bmp;
    bmp = al_load_bitmap((graphicsdir/name).c_str());
    if (bmp == NULL) {
        throw Hexception( "Failed to load bitmap \'"
                          + (graphicsdir/name).string()
                          + "\'\n");
    }
    return bmp;
}

