/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* The Al5GraphicSet provides all the graphics
 * needed by the UI_Engine to display units,
 * terrains and other stuff. */

#ifndef __Al5GraphicSet__H__
#define __Al5GraphicSet__H__

#include <allegro5/allegro.h>
#include <ostream>
#include <string>
#include <vector>

#include "../../filesystem/PathName.hpp"
#include "../../filesystem/FSHandler.hpp"
#include "../../misc/Exceptions.hpp"

class Al5GraphicSet{
public:
    Al5GraphicSet(std::string, FSHandler*);
    ~Al5GraphicSet();

    /** \short lets you choose a new set of images
     *
     * setGraphicSet(std::string) will determine where
     * the desired images are located, unload currently
     * loaded images and then load the new ones.
     */
    void setGraphicSet(std::string);
    
    // bitmaps needed to display terrains
    ALLEGRO_BITMAP* grass1;
    ALLEGRO_BITMAP* water1;
    
    // used to highlight selected units
    ALLEGRO_BITMAP* focus[3];

    ALLEGRO_BITMAP* fogtile;
    ALLEGRO_BITMAP* fog;
    
    // bitmaps for the pointer
    ALLEGRO_BITMAP* cursor[3];
    
    // bitmaps needed to display units
    ALLEGRO_BITMAP* spirit[3];
    ALLEGRO_BITMAP* magician[3];
    ALLEGRO_BITMAP* warrior[3];
    ALLEGRO_BITMAP* scout[3];
    ALLEGRO_BITMAP* terraf[3];

private:
    FSHandler* fsh;

    /// saves where images are saved
    PathName graphicsdir;

    /// loads the graphics
    void loadGraphics();

    /// unloads the graphics
    void unLoadGraphics();

    /** sets all pointers to NULL */
    void setNull();

    /** \short loads bitmap from grapficsdir
     *
     * loadBitmap(const char *) allows to easyly
     * load bitmaps just giving the filename. It
     * throws an Hexception if loading fails so it
     * is quite safe to use.
     *
     * \returns pointer to bitmap on success,
     * NULL if not
     */
    ALLEGRO_BITMAP* loadBitmap(const char*);
};

#endif /* __Al5GraphicSet__H__ */
