/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "Al5UI.hpp"

ALLEGRO_FONT* Al5UI::font = NULL;

Al5UI::Al5UI(){
    ;
}

Al5UI::Al5UI(Coordinates size, Coordinates pos, GraphicSet* gs, Al5UI* par){
    init(size, pos, gs, par);
}

Al5UI::~Al5UI(){
    al_destroy_bitmap(buffer);
    al_destroy_bitmap(TLB);
}

void Al5UI::setGraphicSet(GraphicSet* gs){
    graphics = gs;
}

void Al5UI::print(){
    al_set_target_bitmap(parent->TLB);
    al_draw_bitmap(buffer, pos.x, pos.y, 0);
    al_draw_bitmap(TLB, pos.x, pos.y, 0);
    parent->print();
}

INPUTTYPE Al5UI::getInput(INPUTTYPE currinput){
    return NOINPUT;
}

Coordinates Al5UI::getPointerPos(){
    ALLEGRO_MOUSE_STATE state;
    al_get_mouse_state(&state);
    Coordinates mp = Coordinates(state.x, state.y);
    if(pos < mp && mp < pos + size){
        return mp - pos;
    }
    return Coordinates(-1, -1);
}

void Al5UI::changePos(Coordinates dp){
    pos += dp;
    parent->clearTLB();
}

Coordinates Al5UI::getSize(){
    return size;
}

void Al5UI::setSize(Coordinates s){
    size = s;
    al_destroy_bitmap(TLB);
    TLB = al_create_bitmap(size.x, size.y);
    al_destroy_bitmap(buffer);
    buffer = al_create_bitmap(size.x, size.y);
    clear();
    clearTLB();
}

void Al5UI::printText(std::string text, Coordinates pos){
    al_set_target_bitmap(buffer);
    al_draw_text(font, al_map_rgb(255,255,255), pos.x, pos.y, 0, text.c_str());
}

void Al5UI::init(Coordinates s, Coordinates p, GraphicSet* gs, Al5UI* par){
    graphics = gs;
    parent = par;
    pos = p;
    size = s;
    buffer = al_create_bitmap(size.x, size.y);
    TLB = al_create_bitmap(size.x, size.y);
    clear();
    clearTLB();
}
