/* Hexwars - A Hexagonal Turn Based Strategy Game
 * Copyright (C) 2009-2011  Patrik Schönfeldt
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* The Al5UI_Engine is capable of input and
 * output of the Engine. There might be
 * different versions for different libs
 * (e.g. allegro, glut, ...) in the
 * future. */

#ifndef __Al5UI_Engine__H__
#define __Al5UI_Engine__H__

class Al5UI_Engine;
typedef Al5UI_Engine UI_Engine;

#include <allegro5/allegro.h>
#include <allegro5/allegro_primitives.h>
#include <vector>

#include "../UI_Engine.hpp"
#include "../../../definitions/Coordinates.hpp"
#include "../../../definitions/Map.hpp"
#include "../../../units/Unit.hpp"
#include "../../GraphicSet.hpp"
#include "../../UI.hpp"
#include "../../menu/MenuItem.hpp"

class Al5UI_Engine : public UI{
private:
    Coordinates tilesize;
    Coordinates unitsize;
public:
    /**
     * initializes the user interface of the engine,
     * will create a doublebuffer and load graphics
     */
    Al5UI_Engine(Coordinates s, Coordinates p, GraphicSet* gs, UI* par);

    ~Al5UI_Engine();

    /** Connects the given Coordinates by a line. */
    void drawLine(Coordinates from, Coordinates to, int col);
    void drawLine(std::vector<Coordinates> coos, int col);

    /** Draws the terrain on the given position on the
     * screen or in the window. */
    void drawTerrain(TERRAINTYPE type, Coordinates pos);

    /** Draws the unit on the given position on the
     * screen or in the window. */
    void drawUnit(UNITTYPE type, PLAYER owner, Coordinates pos);

    /** Draws selections. */
    void drawFocus(FOCUSTYPE type, Coordinates pos);

    /**
     *  Used for compatibilty with other libs.
     */
    void lockScreen(bool doit){
        ;
    }

    /**
     *  \returns size of the current GraphicSets' tiles
     */
    Coordinates getTileSize();

    /**
     * This reimplementation of UI::getInput() behaves the same
     * like the original function but it returns ENDROUND instead
     * of SELECT.
     */
    INPUTTYPE getInput();
};


#endif /* __Al5UI_Engine__H__ */
